@@ -62,9 +62,9 @@ class update_properties:
 			if elem['content'] == True:
 				if elem['start'] != None:
 					elem['properties']['date']['start'] = elem['start']
-				if elem['end'] != None:
+				if elem['end'] != None and elem['start'] != None:
 					elem['properties']['date']['end'] = elem['end']
-				if elem['start'] == None and elem['end'] == None:
+				if elem['start'] == None:
 					elem['properties']['date'] == None
 			else :
 				elem['properties']['date'] = self.build_date(elem)
@@ -116,11 +116,9 @@ class update_properties:
 		return elem
 
 	def update_people(self, elem):
-		print(type(self.users))
 		if elem['update'] == True:
 			elem['properties']['people'] = []
 			for people in elem['people']:
-				print(people)
 				for user in self.users:
 					if people == user['name']:
 						elem['properties']['people'].append(user)
